summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDan Crowell <dcrowell@us.ibm.com>2018-05-23 09:54:35 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2018-05-29 10:33:43 -0400
commit4bfa55da9a90424359d3ae5175ddd2863cb75235 (patch)
tree7bb9ea49c5da87ece540e40f373aad2c793b74e0
parenta09327508399ce6d7c9f569f4011b097e92cfdaa (diff)
downloadtalos-hostboot-4bfa55da9a90424359d3ae5175ddd2863cb75235.tar.gz
talos-hostboot-4bfa55da9a90424359d3ae5175ddd2863cb75235.zip
Increase default watchdog timeout to 10 minutes
We have discovered some error cases within the memory diagnostics step where a single hardware operation can take up to 6 minutes to complete. The code sends a watchdog ping before issuing any command, but the current timeout (2 minutes) is insufficient to handle these long commands. Resolves boston-openpower/#1240 Change-Id: I4e27a45c927c014b5fcc28d4510c5996a7009953 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/59254 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: William G. Hoffa <wghoffa@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
-rw-r--r--src/include/usr/ipmi/ipmiwatchdog.H4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/usr/ipmi/ipmiwatchdog.H b/src/include/usr/ipmi/ipmiwatchdog.H
index 324aa86ef..d74ea9300 100644
--- a/src/include/usr/ipmi/ipmiwatchdog.H
+++ b/src/include/usr/ipmi/ipmiwatchdog.H
@@ -43,7 +43,7 @@ namespace IPMIWATCHDOG
// Globals/Constants
/******************************************************************************/
/**
* @brief the default watchdog countdown setting it to 120 seconds.
*
*/
// The config option CONFIG_BMC_IPMI_LONG_WATCHDOG allows a tester to use a
@@ -53,7 +53,7 @@ namespace IPMIWATCHDOG
#ifdef CONFIG_BMC_IPMI_LONG_WATCHDOG
const uint16_t DEFAULT_WATCHDOG_COUNTDOWN = 3600; //60 minutes
#else
-const uint16_t DEFAULT_WATCHDOG_COUNTDOWN = 120; //2 minutes
+const uint16_t DEFAULT_WATCHDOG_COUNTDOWN = 600; //10 minutes
#endif
/**
OpenPOWER on IntegriCloud
@@ -43,7 +43,7 @@ namespace IPMIWATCHDOG
/******************************************************************************/
/**
- * @brief the default watchdog countdown setting it to 120 seconds.
+ * @brief the default watchdog countdown setting it to 600 seconds.
*
*/